==> kagetaka-src-0.2.tar.gz: kagetaka-0.2/src/net/hizlab/kagetaka/awt/TreeItem.java <==
/* ----- BEGIN LICENSE BLOCK -----
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Kagetaka Libraries.
 *
 * The Initial Developer of the Original Code is Hizuya Atsuzaki
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Hizuya Atsuzaki <hizuya@hizlab.net>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ----- END LICENSE BLOCK ----- */
package net.hizlab.kagetaka.awt;

import java.util.Vector;

/**
 * ĥ꡼ΥƥȤƼɬפΤ륤󥿡եǤ
 * 
 * @author  <A HREF="mailto:hizuya@hizlab.net">Hizuya Atsuzaki</A>
 * @version $Revision: 1.2 $
 */
public interface TreeItem
{
	/**
	 * ĥ꡼ɽ٥֤ޤ
	 * 
	 * @return    ĥ꡼ɽ٥
	 */
	public abstract String getTreeLabel();
	
	/**
	 * ҤΥƥ֤ޤ
	 * ⤷<code>null</code> ֤ȡΥƥФƤ
	 * ҥƥɲäǤʤʤޤ
	 * 
	 * @return    ҤΥƥ
	 */
	public abstract Vector getTreeItems();
	
	/**
	 * ҤΥƥɲäޤ
	 * 
	 * @param     item  ƥ
	 * @param     index ǥåǸɲä <code>-1</code>
	 * 
	 * @return    ɲä줿 <code>true</code>
	 *            ʳξ <code>false</code>
	 */
	public abstract boolean addTreeItem(TreeItem item, int index);
	
	/**
	 * ҤΥƥޤ
	 * 
	 * @param     index ǥå
	 */
	public abstract void removeTreeItem(int index);
	
	/**
	 * ƤΥƥ֤ޤ
	 * 
	 * @return    ƥƥ
	 */
	public abstract TreeItem getParentTreeItem();
}

==> kagetaka-src-0.3.1.tar.gz: kagetaka-0.3.1/src/net/hizlab/kagetaka/awt/TreeItem.java <==
/* ----- BEGIN LICENSE BLOCK -----
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Kagetaka Libraries.
 *
 * The Initial Developer of the Original Code is Hizuya Atsuzaki
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Hizuya Atsuzaki <hizuya@hizlab.net>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ----- END LICENSE BLOCK ----- */
package net.hizlab.kagetaka.awt;

import java.awt.Image;
import java.util.Vector;

/**
 * ĥ꡼ΥƥȤƼɬפΤ륤󥿡եǤ
 * 
 * @author  <A HREF="mailto:hizuya@hizlab.net">Hizuya Atsuzaki</A>
 * @version $Revision: 1.3 $
 */
public interface TreeItem
{
	/**
	 * ĥ꡼ɽ륢֤ޤ
	 * 
	 * @param     opened Ƥեξ <code>true</code>
	 *                   ʳξ <code>false</code>
	 * 
	 * @return    ĥ꡼ɽ륢
	 *            ɽʤ <code>null</code>
	 */
	public Image getTreeIcon(boolean opened);
	
	/**
	 * ĥ꡼ɽ٥֤ޤ
	 * 
	 * @return    ĥ꡼ɽ٥롣
	 *            ѥ졼ɽ <code>null</code>
	 */
	public abstract String getTreeLabel();
	
	/**
	 * ҤΥƥ֤ޤ
	 * ⤷<code>null</code> ֤ȡΥƥФƤ
	 * ҥƥɲäǤʤʤޤ
	 * 
	 * @return    ҤΥƥ
	 */
	public abstract Vector getTreeItems();
}
